@@ -24,7 +24,7 @@ CLEANUP_INTERVAL_MS = 0.999
 
 def random_token(length=10):
     alphabet = string.ascii_letters + string.digits
-    return join(random.choice(alphabet) for i in range(length))
+    return "".join(random.choice(alphabet) for i in range(length))
 
 
 class BatchProcessor:
@@ -41,10 +41,10 @@ class BatchProcessor:
             logger.warning("Skipping database initialization")
         else:
             self.db = Database(self.config)
-        logger.warning(f"Batch Processor {self.worker_id} instanciated")
+        logger.info(f"Batch Processor {self.worker_id} instanciated")
 
     def __del__(self):
-        logger.warning(f"Batch Processor {self.worker_id} deleted")
+        logger.info(f"Batch Processor {self.worker_id} deleted")
         self.worker_id = None
 
     def verify(self):
@@ -400,12 +400,17 @@ class BatchProcessor:
         raw = self.db.get_job_times()
         return raw
 
+    def get_worker_stats(self):
+        raw = self.db.get_worker_stats()
+        return raw
+
     def get_status(self):
         # fmt: off
         status = {
              "status": self.db.get_status_counts()
             , "counts": self.get_job_counts()
             , "times": self.get_job_times()
+            , "workers": self.get_worker_stats()
         }
         # fmt: on
         return status
